@@ -4,6 +4,7 @@
 * env
 * gitstatus
 * job
+* times
 * vc
 * base
 
@@ -422,6 +423,18 @@ def _current_job():
                 s = cmd[1]
             return s
 
+#
+# times
+#
+# -*- coding: utf-8 -*-
+"""date & time related prompt formatter"""
+time = _LazyModule.load('time', 'time')
+# amalgamated builtins
+def _localtime():
+    pf = builtins.__xonsh__.env.get("PROMPT_FIELDS", {})
+    tf = pf.get("time_format", "%H:%M:%S")
+    return time.strftime(tf, time.localtime())
+
 #
 # vc
 #
@@ -435,7 +448,17 @@ queue = _LazyModule.load('queue', 'queue')
 # amalgamated builtins
 threading = _LazyModule.load('threading', 'threading')
 # amalgamated subprocess
+re = _LazyModule.load('re', 're')
 # amalgamated xonsh.tools
+from xonsh.lazyasd import LazyObject
+
+RE_REMOVE_ANSI = LazyObject(
+    lambda: re.compile(r"(?:\x1B[@-_]|[\x80-\x9F])[0-?]*[ -/]*[@-~]"),
+    globals(),
+    "RE_REMOVE_ANSI",
+)
+
+
 def _get_git_branch(q):
     denv = builtins.__xonsh__.env.detype()
     try:
@@ -474,6 +497,9 @@ def get_git_branch():
     t.join(timeout=timeout)
     try:
         branch = q.get_nowait()
+        # branch = RE_REMOVE_ANSI.sub("", branch or "")
+        if branch:
+            branch = RE_REMOVE_ANSI.sub("", branch)
     except queue.Empty:
         branch = None
     return branch
@@ -696,7 +722,7 @@ def branch_bg_color():
 # amalgamated builtins
 itertools = _LazyModule.load('itertools', 'itertools')
 # amalgamated os
-re = _LazyModule.load('re', 're')
+# amalgamated re
 socket = _LazyModule.load('socket', 'socket')
 # amalgamated sys
 # amalgamated xonsh.lazyasd
@@ -707,6 +733,7 @@ socket = _LazyModule.load('socket', 'socket')
 # amalgamated xonsh.prompt.env
 # amalgamated xonsh.prompt.vc
 # amalgamated xonsh.prompt.gitstatus
+# amalgamated xonsh.prompt.times
 @xt.lazyobject
 def DEFAULT_PROMPT():
     return default_prompt()
@@ -790,6 +817,8 @@ def PROMPT_FIELDS():
         env_postfix=") ",
         vte_new_tab_cwd=vte_new_tab_cwd,
         gitstatus=gitstatus_prompt,
+        time_format="%H:%M:%S",
+        localtime=_localtime,
     )
 
 
